==================================
bisos.bashStandaloneIcmSeed Script
==================================

.. contents::
   :depth: 3
..

Overview
========

Bash seed script for standalone ICM (Interactive Command Modules) for
use by standalone bash ICMs which are often used for bootstraping.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Installation
============

::

   sudo pip install bisos.bashStandaloneIcmSeed

Usage
=====

seedIcmStandalone.bash
----------------------

| Installing this package results in creation of:
| **/usr/local/bin/seedIcmStandalone.bash**

A standalone ICM can then use that seed.

See **bisos.bashStandaloneIcmExample** for an example.
